"""Entry point"""
#!/usr/bin/env python

import logging
import sys

from xmlrpc.server import SimpleXMLRPCServer

import RPi.GPIO as GPIO

LOG_LEVEL = logging.ERROR
LOG_FILE = "/var/log/relay_rpc.log"
LOG_FORMAT = "%(asctime)s %(levelname)s %(message)s"

HOST = "0.0.0.0"
PORT = 64001

GPIOS = [26, 20, 21]


def switch_relay(relay: int, state: bool):
    """Switch relay"""
    pin = int(GPIOS[relay - 1])
    log = logging.getLogger()
    log.info("switching relay %s (pin %s) %s", relay, pin, state)
    GPIO.output(pin, not state)

def get_relay_state(relay: int) -> bool:
    pin = int(GPIOS[relay - 1])
    state = GPIO.input(pin)
    log = logging.getLogger()
    log.info("Relay state of relay %s (pin %s) %s", relay, pin, state)
    return state

def init_relays():
    """Init relays"""
    GPIO.setwarnings(False)
    GPIO.setmode(GPIO.BCM)
    for pin in GPIOS:
        GPIO.setup(pin, GPIO.OUT)
        GPIO.output(pin, True)


def main():
    """Entry point"""
    logging.basicConfig(format=LOG_FORMAT, level=LOG_LEVEL, filename=LOG_FILE)
    # logging.basicConfig(format=LOG_FORMAT, level=LOG_LEVEL)

    log = logging.getLogger()

    init_relays()

    server = SimpleXMLRPCServer((HOST, PORT), allow_none=True)

    server.register_function(switch_relay, 'switch_relay')
    server.register_function(get_relay_state, 'get_relay_state')

    log.info('Control-c to quit')
    server.serve_forever()
    log.info("Shutting down...")
    log.info("...done. Exiting...")


if __name__ == '__main__':
    sys.exit(main())
